@@ -1,7 +1,7 @@
 CAvariants <-
 function(
   Xtable, mj=NULL,mi=NULL,firstaxis=1,lastaxis=2,
-  catype = "CA",ellcomp=TRUE,Mell=min(nrow(Xtable),ncol(Xtable))-1,alpha=0.05) { 
+  catype = "CA",ellcomp=TRUE,M=min(nrow(Xtable),ncol(Xtable))-1,alpha=0.05) { 
 #if (printdims<1) stop(paste("Attention: number of dims for output must be at least 1\n\n"))
 if (lastaxis<2) stop(paste("Attention: last axis must be at least 2\n\n"))
 if (!any(catype==c("CA","SOCA","DOCA","NSCA","SONSCA","DONSCA"))) stop(paste("Must be CA, DOCA, SOCA, NSCA, SONSCA or DONSCA"))
@@ -42,7 +42,7 @@ pcc <- t(S$CX)
 #dimnames(pcc)<-dimnames(X)
 tau=NULL
 tauden=NULL
-inertia <- (S$mu[1:r]*S$mu[1:r])
+inertia <- (S$mu[1:r]^2)/n #please check!!
 comps<-diag(inertia)
 Trend<-(Fmat[,firstaxis:lastaxis]%*%t(Gbi[,firstaxis:lastaxis]))
 Z<-Trend
@@ -54,15 +54,18 @@ Z<-S$Z/sqrt(n)
 pcc<-S$RX #centered column profile matrix
 Gbi <- S$Raxes[,1:r]
 Fbi<- S$Caxes[,1:r] 
+Gbi2 <- S$Raxes
+Fbi2<- S$Caxes
+
 Gmat <-  S$CX %*%  S$Caxes[,1:r] #row principal coordinates
 Fmat <- S$RX  %*% S$Raxes[,1:r] #column principal coordinates
 nr<-nrow(Z)
 nc<-ncol(Z)
-if (nr>2){
-if  ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){
-Gmat<-(-1)*Gmat
-Fmat<-(-1)*Fmat
-}}
+#if (nr>2){
+#if  ((Z[2,2]<0) & (Z[1,2]>0)||(Z[2,2]>0) & (Z[1,2]<0)){
+#Gmat<-(-1)*Gmat
+#Fmat<-(-1)*Fmat
+#}}
 reconstruction<-t(Gmat%*%t(S$Cweights%*%Fbi))
 dimnames(reconstruction)<-dimnames(X)
 inertia <- S$mu[1:r]/n #number of inertia of row poly
@@ -103,7 +106,11 @@ nc<-ncol(Z)
 dimnames(pcc)<-dimnames(X)
 Gmat <- S$CX %*%  S$Caxes[,1:r] #row principal coordinates
 Fmat <- S$RX %*% S$Rweights %*% S$Raxes[,1:r] #column principal coordinates
-if ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){Gmat<-(-1)*Gmat}
+#if (nr>2){
+#if  ((Z[2,2]<0) & (Z[1,2]>0)||(Z[2,2]>0) & (Z[1,2]<0)){
+#Gmat<-(-1)*Gmat
+#Fmat<-(-1)*Fmat
+#}}
 Gbi <-S$Raxes[,1:r]
 Fbi <- S$Caxes[,1:r] 
 inertia <- (S$mu[1:r]^2)/n
@@ -139,7 +146,7 @@ dimnames(pcc)<-dimnames(X)
 Gmat <-  S$Raxes[,1:r] %*% dmum1
 Fmat <- S$Caxes[,1:r] %*% dmum1
 tauden<-S$tauDen
-inertia <- S$mu[1:r]*S$mu[1:r]
+inertia <- S$mu[1:r]^2
 tau<-sum(inertia)/tauden
 comps<-diag(inertia)
 Trend<-(Fmat[,firstaxis:lastaxis]%*%t(S$Rweights%*%Gbi[,firstaxis:lastaxis]))
@@ -158,7 +165,11 @@ nc<-ncol(Z)
 dimnames(pcc)<-dimnames(X)
 Gmat <-  S$CX %*% S$Cweights %*% S$Caxes[,1:r] #row principal coordinates
 Fmat <- S$RX  %*% S$Rweights %*% S$Raxes[,1:r] #column principal coordinates
-if  ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){Gmat<-(-1)*Gmat}
+#if (nr>2){
+#if  ((Z[2,2]<0) & (Z[1,2]>0)||(Z[2,2]>0) & (Z[1,2]<0)){
+#Gmat<-(-1)*Gmat
+#Fmat<-(-1)*Fmat
+#}}
 inertia <- S$mu[1:r]
 inertia2<-S$mu2[1:r] 
 tauden<-S$tauDen
@@ -200,9 +211,11 @@ Fmat <- S$RX %*% (S$Rweights) %*% S$Raxes[,1:r] #row principal coordinates with
 Gbi <- S$Raxes[,1:r]
 #Gbi<-(sqrt(S$Rweights))%*%S$Raxes
 Fbi <- S$Caxes[,1:r] 
-if ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){Gmat<-(-1)*Gmat
-#Fbi<-(-1)*Fbi
-}
+#if (nr>2){
+#if  ((Z[2,2]<0) & (Z[1,2]>0)||(Z[2,2]>0) & (Z[1,2]<0)){
+#Gmat<-(-1)*Gmat
+#Fmat<-(-1)*Fmat
+#}}
 inertia <- S$mu[1:r]
 inertia2 <- S$mu2[1:r]
 tauden<-S$tauDen
@@ -265,49 +278,44 @@ dimnames(Gbi)<-list(collabels,paste("axes", 1:r,sep=""))
 names(mi)<-rowlabels
 names(mj)<-collabels
 #---------------------------------------------------
-if (ellcomp==TRUE){
-cord1<-Gmat
+#if (ellcomp==TRUE){
+cord1<-Gmat #check here
 cord2<-Fmat
-if ((catype=="DOCA")|(catype=="SOCA")|(catype=="SONSCA")|(catype=="DONSCA") ){
+if ((catype=="DOCA")|(catype=="SOCA")|(catype=="SONSCA")|(catype=="DONSCA")){
 cordr<-cord2
 cordc<-cord1
 cord1<-cordr
 cord2<-cordc
 }
+#----------------------------------------------------------------------
+#for printing the length of the ellipses axes 
+#--------------------------------------------------
+if (ellcomp==TRUE){
+resellprint<-switch(catype, "CA"=caellipseprint(Xtable=X,a1=firstaxis,a2=lastaxis,alpha=alpha,M=M,
+Imass=dr,Jmass=dc,a=Fbi,b=Gbi,g=cord1,f=cord2,dmu=diag(inertias[,1]),inertiapc=round(inertias[,2],digits=1)),
 
-risell<-switch(catype, "CA"=caellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
-Imass=dr,Jmass=dc,a=Fbi,b=Gbi,g=cord1,fr=cord2,dmu=diag(inertias[,1]),inertiapc=round(inertias[,2],digits=1),
-plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE), 
+"SOCA"=caellipseprint(Xtable=X,a1=1,a2=2,alpha=alpha,M=M,
+Imass=dr,Jmass=dc,a=Fbi,b=Gbi,g=cord2,f=cord1,dmu=diag(inertias2[,1]),inertiapc=round(inertias2[,2],digits=1)),
 
-"SOCA"=caellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
-Imass=dr,Jmass=dc,a=Fbi,b=Gbi,g=cord2,fr=cord1,dmu=diag(inertias2[,1]),inertiapc=round(inertias2[,2],digits=1),
-plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE), 
-
-"DOCA"=caellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
+"DOCA"=caellipseprint(Xtable=X,a1=1,a2=2,alpha=alpha,M=M,
 Imass=dr,Jmass=dc,a=Fbi,
-b=Gbi,g=cord2,fr=cord1,dmu=diag(inertias2[,1]),inertiapc=round(inertias2[,2],digits=1),
-plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE), 
+b=Gbi,g=cord2,f=cord1,dmu=diag(inertias2[,1]),inertiapc=round(inertias2[,2],digits=1)),
 
-"NSCA"=nscaellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
+"NSCA"=nscaellipseprint(Xtable=X,a1=1,a2=2,alpha=alpha,M=M,
 Imass=dr,Jmass=dc,a=Fbi,
-b=Gbi,g=cord1,fr=cord2,dmu=diag(inertias[,1]), tauden=tauden,
-inertiapc=round(inertias[,2],digits=1),
-plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE),
+b=Gbi,g=cord1,f=cord2,dmu=diag(inertias[,1]), tauden=tauden,
+inertiapc=round(inertias[,2],digits=1)),
 
-"SONSCA"=nscaellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M= Mell,prop=.8,
+"SONSCA"=nscaellipseprint(Xtable=X,a1=1,a2=2,alpha=alpha,M= M,
 Imass=dr,Jmass=dc,a=Fbi,
-b=Gbi,g=cord2,fr=cord1,dmu=diag(inertias2[,1]),tauden=tauden,inertiapc=round(inertias2[,2],digits=1),
-plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE), 
+b=Gbi,g=cord2,f=cord1,dmu=diag(inertias2[,1]),tauden=tauden,inertiapc=round(inertias2[,2],digits=1)),
 
-"DONSCA"=nscaellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
+"DONSCA"=nscaellipseprint(Xtable=X,a1=1,a2=2,alpha=alpha,M=M,
 Imass=dr,Jmass=dc,a=Fbi,
-b=Gbi,g=cord2,fr=cord1,dmu=diag(inertias2[,1]),tauden=tauden,inertiapc=round(inertias2[,2],digits=1),
-plottype="biplot",biptype="row",pos=1,arrow=F,length=0,graphy=FALSE,ell=FALSE))
-dimnames(risell$row.summ)[[1]]<-dimnames(X)[[1]]
-dimnames(risell$col.summ)[[1]]<-dimnames(X)[[2]]
+b=Gbi,g=cord2,f=cord1,dmu=diag(inertias2[,1]),tauden=tauden,inertiapc=round(inertias2[,2],digits=1)))
 }#end ellcomp
 else{
-risell<-NULL}
+resellprint<-NULL}
 #############################
 #invisible(x<- new("cacorporateplus",S=S,
 #DataMatrix=X, rows=rows, cols=cols, r=r,
@@ -321,7 +329,7 @@ rowlabels=rowlabels, collabels=collabels,
 Rprinccoord=Fmat, Cprinccoord=Gmat, Rstdcoord=Fbi, Cstdcoord=Gbi,tauden=tauden,tau=tau,
  inertiasum=inertiasum, inertias=inertias, inertias2=inertias2,comps=comps,
  catype=catype,mj=mj,mi=mi,pcc=pcc,Jmass=dc,Imass=dr,
-Trend=Trend,Z=Z,ellcomp=ellcomp,risell=risell,Mell=Mell)
+Trend=Trend,Z=Z,ellcomp=ellcomp,resellprint=resellprint,M=M)
 class(resultCA)<-"CAvariants"
 return(resultCA)
 #-----------------------------------------------
