@@ -1,7 +1,7 @@
 caellipse <-
 function (Xtable, a1=1,a2=2,alpha = 0.05, cols = c(2, 4), M = 2, cex =0.8, cex.lab = 0.8, mar = c(5, 4, 4, 2) + 0.1, 
- prop=0.8,Imass,Jmass,a,b,g,fr,dmu,inertiapc,plottype="biplot",biptype="row",
-pos=2,arrow=TRUE,length=0,graphy=TRUE,ell=TRUE) 
+ prop=0.8,Imass,Jmass,a,b,g,f,dmu,inertiapc,plottype="biplot",biptype="row",
+pos=2,arrow=TRUE,length=0,ell=TRUE) 
 {
     I <- nrow(Imass)
     J <- nrow(Jmass)
@@ -10,7 +10,7 @@ rowgroup <- list(1:I,rep(1,I))
 rowgrlab <- list(1,"","*","blue","T")
 colgroup <- list(1:J,rep(1,J))
 colgrlab <- list(1,"","+","red","T")
-    Inames <- dimnames(fr)[1]
+    Inames <- dimnames(f)[1]
     Jnames <- dimnames(g)[1]
     dIh <- solve(Imass^0.5)
     dJh <- solve(Jmass^0.5)
@@ -24,44 +24,43 @@ chisq.val <- qchisq(1 - alpha, df = (I - 1) * (J - 1))
 #browser()
     if (M > 2) {
         for (i in 1:I) {
-            hlax1.row[i] <- dmu[1,1] * sqrt(abs((chisq.val/(t.inertia*n)) * 
+            hlax1.row[i] <- dmu[a1,a1] * sqrt(abs((chisq.val/(t.inertia*n)) * 
                 (1/Imass[i,i] - sum(a[i, 3:M]^2))))
-            hlax2.row[i] <- dmu[2,2] * sqrt(abs((chisq.val/(t.inertia*n)) * 
+            hlax2.row[i] <- dmu[a2,a2] * sqrt(abs((chisq.val/(t.inertia*n)) * 
                 (1/Imass[i,i] - sum(a[i, 3:M]^2))))
         }
         for (j in 1:J) {
-            hlax1.col[j] <- dmu[1,1] * sqrt(abs((chisq.val/(t.inertia*n)) * 
+            hlax1.col[j] <- dmu[a1,a1] * sqrt(abs((chisq.val/(t.inertia*n)) * 
                 (1/Jmass[j,j] - sum(b[j, 3:M]^2))))
-            hlax2.col[j] <- dmu[2,2] * sqrt(abs((chisq.val/(t.inertia*n)) * 
+            hlax2.col[j] <- dmu[a2,a2] * sqrt(abs((chisq.val/(t.inertia*n)) * 
                 (1/Jmass[j,j] - sum(b[j, 3:M]^2))))
         }
     }
     else {
         for (i in 1:I) {
-            hlax1.row[i] <- dmu[1,1] * sqrt(abs((chisq.val/(t.inertia*n)) * 
+            hlax1.row[i] <- dmu[a1,a1] * sqrt(abs((chisq.val/(t.inertia*n)) * 
                 (1/(Imass)[i,i])))
-            hlax2.row[i] <- dmu[2,2] * sqrt(abs((chisq.val/(t.inertia*n)) * 
+            hlax2.row[i] <- dmu[a2,a2] * sqrt(abs((chisq.val/(t.inertia*n)) * 
                 (1/(Imass)[i,i])))
         }
         for (j in 1:J) {
-            hlax1.col[j] <- dmu[1,1] * sqrt(abs((chisq.val/(t.inertia*n)) * 
+            hlax1.col[j] <- dmu[a1,a1] * sqrt(abs((chisq.val/(t.inertia*n)) * 
                 (1/(Jmass)[j,j])))
-            hlax2.col[j] <- dmu[2,2] * sqrt(abs((chisq.val/(t.inertia*n)) * 
+            hlax2.col[j] <- dmu[a2,a2] * sqrt(abs((chisq.val/(t.inertia*n)) * 
                 (1/(Jmass)[j,j])))
         }
     }
-if (graphy==TRUE){
-picsize<-c(range(fr[,c(a1,a2)], g[,c(a1,a2)])/prop)
-    plot.new()
+picsize<-c(range(f[,c(a1,a2)], g[,c(a1,a2)])/prop)
+ #   plot.new()
     par(pty = "s", mar = mar)
 #browser()
-#plot(fr[, a1], fr[, a2], xlim=picsize, ylim=picsize, 
+#plot(f[, a1], f[, a2], xlim=picsize, ylim=picsize, 
 plot(0,0,pch=" ", xlim=picsize, ylim=picsize, 
  xlab=paste("Axis ", a1, "    ", inertiapc[a1], "%", sep=""), 
  ylab=paste("Axis ", a2, "    ", inertiapc[a2], "%", sep=""),  asp=1,col=rowgrlab[[4]][as.integer(rowgroup[[2]])],cex=cex,cex.lab=cex.lab)
 abline(h = 0, v = 0) 
-text(fr[, a1], fr[, a2], labels = Inames[[1]], pos= pos, col = cols[1], cex = cex)
-points(fr[, a1], fr[, a2], pch="*",col=cols[1],cex=cex)
+text(f[, a1], f[, a2], labels = Inames[[1]], pos= pos, col = cols[1], cex = cex)
+points(f[, a1], f[, a2], pch="*",col=cols[1],cex=cex)
     text(g[, a1], g[, a2], labels = Jnames[[1]], pos= pos, col = cols[2], 
         cex = cex)
 points(g[, a1], g[, a2], pch="+",col=cols[2],cex=cex)
@@ -83,13 +82,13 @@ arrows(nv, nv, g[,a1], g[, a2], length = length)
 } #end col
 if ((biptype=="row")|(biptype=="r")|(biptype=="rows")){
 #----------------------------------------------arrow on row principal coords
-nv <- rep(0, nrow(fr))
+nv <- rep(0, nrow(f))
 if(arrow) {
-arrows(nv, nv, fr[, a1], fr[,a2], length = length)
+arrows(nv, nv, f[, a1], f[,a2], length = length)
 }
 if (ell){
  for (i in 1:I) {
-        ellipse(hlax1.row[i], hlax2.row[i], xc = fr[i, a1], yc = fr[i, 
+        ellipse(hlax1.row[i], hlax2.row[i], xc = f[i, a1], yc = f[i, 
             a2], col = cols[1])
     }
 } }#end row end ell
@@ -103,12 +102,11 @@ else{ # when classical
     }
  
 for (i in 1:I) {
-        ellipse(hlax1.row[i], hlax2.row[i], xc = fr[i, a1], yc = fr[i, 
+        ellipse(hlax1.row[i], hlax2.row[i], xc = f[i, a1], yc = f[i, 
            a2], col = cols[1])
     }
 }#end else
-}#end graphy
-    eccentricity <- abs(1 - (dmu[2, 2]^2/dmu[1, 1]^2))^(1/2)
+    eccentricity <- abs(1 - (dmu[a2, a2]^2/dmu[a1, a1]^2))^(1/2)
     area.row <- vector(mode = "numeric", length = I)
     area.col <- vector(mode = "numeric", length = J)
     for (i in 1:I) {
@@ -122,24 +120,24 @@ for (i in 1:I) {
     for (i in 1:I) {
         if (M > 2) {
             pvalrow[i] <- 1- pchisq(t.inertia *n* ((1/Imass[i,i] - sum(a[i, 
-                3:M]^2))^(-1)) * (fr[i, 1]^2/dmu[1, 1]^2 + fr[i, 
-                2]^2/dmu[2, 2]^2), df = (I - 1) * (J - 1))
+                3:M]^2))^(-1)) * (f[i, a1]^2/dmu[a1, a1]^2 + f[i, 
+                a2]^2/dmu[a2, a2]^2), df = (I - 1) * (J - 1))
         }
         else {
             pvalrow[i] <- 1-pchisq(t.inertia*n * (Imass[i,i]) * 
-                (fr[i, 1]^2/dmu[1, 1]^2 + fr[i, 2]^2/dmu[2, 2]^2), 
+                (f[i, a1]^2/dmu[a1, a1]^2 + f[i, a2]^2/dmu[a2, a2]^2), 
                 df = (I - 1) * (J - 1))
         }
     }
     for (j in 1:J) {
         if (M > 2) {
             pvalcol[j] <-  1-pchisq(t.inertia *n* ((1/Jmass[j,j] - 
-                sum(b[j, 3:M]^2))^(-1)) * (g[j, 1]^2/dmu[1, 1]^2 + 
-                g[j, 2]^2/dmu[2, 2]^2), df = (I - 1) * (J - 1))
+                sum(b[j, 3:M]^2))^(-1)) * (g[j, a1]^2/dmu[a1, a1]^2 + 
+                g[j, a2]^2/dmu[a2, a2]^2), df = (I - 1) * (J - 1))
         }
         else {
             pvalcol[j] <- 1- pchisq(t.inertia *n* (Jmass[j,j]) * 
-                (g[j, 1]^2/dmu[1, 1]^2 + g[j, 2]^2/dmu[2, 2]^2), 
+                (g[j, a1]^2/dmu[a1, a1]^2 + g[j, a2]^2/dmu[a2, a2]^2), 
                 df = (I - 1) * (J - 1))
         }
     }
