@@ -1,6 +1,6 @@
 nscaellipse <-
 function(Xtable, a1=1,a2=2,alpha = 0.05, cols = c(2, 4), M = 2, cex = .8, cex.lab = 0.8, mar = c(5, 4, 4, 2) + 0.1,  
-prop=.8,Imass,Jmass,a,b,fr,g,dmu,tauden,inertiapc,plottype="biplot",biptype="row",pos=2,arrow=TRUE,length=0,graphy=TRUE,ell=TRUE) 
+prop=.8,Imass,Jmass,a,b,f,g,dmu,tauden,inertiapc,plottype="biplot",biptype="row",pos=2,arrow=TRUE,length=0,ell=TRUE) 
  {
   I <- nrow(Imass)
     J <- nrow(Jmass)
@@ -9,12 +9,8 @@ rowgroup <- list(1:I,rep(1,I))
 rowgrlab <- list(1,"","*","blue","T")
 colgroup <- list(1:J,rep(1,J))
 colgrlab <- list(1,"","+","red","T")
-    Inames <- dimnames(fr)[1]
+    Inames <- dimnames(f)[1]
     Jnames <- dimnames(g)[1]
-    dIh <- solve(Imass^0.5)
-    dJh <- solve(Jmass^0.5)
-#if ((catype=="SONSCA")|(catype=="DONSCA")){
-#b <- dJh %*% b}
      t.inertia <- (sum(dmu)/tauden)*(n-1)*(I-1)
    #    t.inertia2 <- (sum(dmu^2))
  dmu<-sqrt(dmu)
@@ -26,44 +22,43 @@ colgrlab <- list(1,"","+","red","T")
     hlax2.col <- vector(mode = "numeric", length = J)
 if (M > 2) {
         for (i in 1:I) {
-            hlax1.row[i] <- dmu[1, 1] * sqrt(abs((chisq.val/t.inertia) * 
+            hlax1.row[i] <- dmu[a1, a1] * sqrt(abs((chisq.val/t.inertia) * 
                 (1 - sum(a[i, 3:M]^2))))
-            hlax2.row[i] <- dmu[2, 2] * sqrt(abs((chisq.val/t.inertia) * 
+            hlax2.row[i] <- dmu[a2, a2] * sqrt(abs((chisq.val/t.inertia) * 
                 (1 - sum(a[i, 3:M]^2))))
         }
         for (j in 1:J) {
-            hlax1.col[j] <- dmu[1, 1] * sqrt(abs((chisq.val/t.inertia) * 
+            hlax1.col[j] <- dmu[a1, a1] * sqrt(abs((chisq.val/t.inertia) * 
                 (1/Jmass[j,j] - sum(b[j, 3:M]^2))))
-            hlax2.col[j] <- dmu[2, 2] * sqrt(abs((chisq.val/t.inertia) * 
+            hlax2.col[j] <- dmu[a2, a2] * sqrt(abs((chisq.val/t.inertia) * 
                 (1/Jmass[j,j] - sum(b[j, 3:M]^2))))
         }
     }
     else {
         for (i in 1:I) {
-            hlax1.row[i] <- dmu[1, 1] * sqrt(chisq.val/t.inertia)
-            hlax2.row[i] <- dmu[2, 2] * sqrt(chisq.val/t.inertia) 
+            hlax1.row[i] <- dmu[a1, a1] * sqrt(chisq.val/t.inertia)
+            hlax2.row[i] <- dmu[a2, a2] * sqrt(chisq.val/t.inertia) 
         }
         for (j in 1:J) {
-            hlax1.col[j] <- dmu[1, 1] * sqrt((chisq.val/t.inertia) * 
+            hlax1.col[j] <- dmu[a1, a1] * sqrt((chisq.val/t.inertia) * 
                 1/Jmass[j,j])
-            hlax2.col[j] <- dmu[2, 2] * sqrt((chisq.val/t.inertia) * 
+            hlax2.col[j] <- dmu[a2, a2] * sqrt((chisq.val/t.inertia) * 
                 1/Jmass[j,j])
         }
     }
-
-if (graphy==TRUE){   
-picsize<-c(range(fr[,c(a1,a2)], g[,c(a1,a2)])/prop)
-plot.new()
+   
+picsize<-c(range(f[,c(a1,a2)], g[,c(a1,a2)])/prop)
+#plot.new()
  par(pty = "s", mar = mar)
-#plot(fr[, a1], fr[, a2],xlim=picsize, ylim=picsize, 
+#plot(f[, a1], f[, a2],xlim=picsize, ylim=picsize, 
   plot(0, 0,pch=" ",xlim=picsize, ylim=picsize, 
     xlab=paste("Axis ", a1, "    ", inertiapc[a1], "%", sep=""), 
      ylab=paste("Axis ", a2, "    ", inertiapc[a2], "%", sep=""),  
  asp=0,  col=rowgrlab[[4]][as.integer(rowgroup[[2]])],cex=cex,cex.lab=cex.lab)
 abline(h=0,v=0)
-text(fr[, a1], fr[, a2], labels = Inames[[1]],pos=pos,col = cols[1], 
+text(f[, a1], f[, a2], labels = Inames[[1]],pos=pos,col = cols[1], 
         cex = cex)
-points(fr[, a1], fr[, a2], pch="*",col=cols[1],cex=cex)
+points(f[, a1], f[, a2], pch="*",col=cols[1],cex=cex)
     text(g[, a1], g[, a2], labels = Jnames[[1]], pos=pos, col = cols[2], 
         cex = cex)
 points(g[, a1], g[, a2], pch="+",col=cols[2],cex=cex)
@@ -86,15 +81,15 @@ arrows(nv, nv, g[,a1], g[, a2], length = length)
 }#end biptype
 if ((biptype=="row")|(biptype=="r")|(biptype=="")){
 #----------------------------------------------arrow on row principal coords
-nv <- rep(0, nrow(fr))
-#vec <- fr[, c(a1, a2)]
+nv <- rep(0, nrow(f))
+#vec <- f[, c(a1, a2)]
 if(arrow) {
-arrows(nv, nv, fr[, a1], fr[, a2], length = length)
+arrows(nv, nv, f[, a1], f[, a2], length = length)
 }
 #-------------------------------------------------------------
 if (ell){
 for (i in 1:I) {
-        ellipse(hlax1.row[i], hlax2.row[i], xc = fr[i, a1], yc = fr[i, 
+        ellipse(hlax1.row[i], hlax2.row[i], xc = f[i, a1], yc = f[i, 
             a2], col = cols[1])
     }
 }}#end row end ell
@@ -106,14 +101,12 @@ else {#when classic
             a2], col = cols[2])
     }
 for (i in 1:I) {
-        ellipse(hlax1.row[i], hlax2.row[i], xc = fr[i, a1], yc = fr[i, 
+        ellipse(hlax1.row[i], hlax2.row[i], xc = f[i, a1], yc = f[i, 
             a2], col = cols[1])
     }
 }#end else
-}#end graphy
-
 #----------------------------------------
-   eccentricity <- abs(1 - (dmu[2, 2]/dmu[1, 1])^2)^(1/2)
+   eccentricity <- abs(1 - (dmu[a2, a2]/dmu[a1, a1])^2)^(1/2)
     area.row <- vector(mode = "numeric", length = I)
     area.col <- vector(mode = "numeric", length = J)
     for (i in 1:I) {
@@ -127,22 +120,21 @@ for (i in 1:I) {
     for (i in 1:I) {
         if (M > 2) {
             pvalrow[i] <- 1 - pchisq(t.inertia * ((1 - sum(a[i, 
-                3:M]^2))^(-1)) * (fr[i, 1]^2/dmu[1, 1]^2 + fr[i, 
-                2]^2/dmu[2, 2]^2), df = (I - 1) * (J - 1))
+                3:M]^2))^(-1)) * (f[i, a1]^2/dmu[a1, a1]^2 + f[i, 
+                a2]^2/dmu[a2, a2]^2), df =  (J - 1))
         }
         else {
             pvalrow[i] <- 1 - pchisq(t.inertia *
-                (fr[i, 1]^2/dmu[1, 1]^2 + fr[i, 2]^2/dmu[2, 2]^2), 
-                df = (I - 1) * (J - 1))
+                (f[i, a1]^2/dmu[a1, a1]^2 + f[i, a2]^2/dmu[a2, a2]^2), 
+                df =  (J - 1))
         }
     }
     for (j in 1:J) {
         if (M > 2) {
-       #     pvalcol[j] <- 1 - pchisq(t.inertia*(n - 1) * (I - 1)* ((1/Jmass[j,j] - 
-pvalcol[j] <- 1 - pchisq(t.inertia * (1/Jmass[j,j] - sum(b[j, 3:M]^2))^(-1) * (g[j, 1]^2/dmu[1, 1]^2 +g[j, 2]^2/dmu[2, 2]^2), df = (I - 1) * (J - 1))
+    pvalcol[j] <- 1 - pchisq(t.inertia * (1/Jmass[j,j] - sum(b[j, 3:M]^2))^(-1) * (g[j, a1]^2/dmu[a1, a1]^2 +g[j, a2]^2/dmu[a2,a2]^2), df = (I - 1) )
         }
         else {
-  pvalcol[j] <- 1 - pchisq(t.inertia* (Jmass[j,j])*(g[j, 1]^2/dmu[1, 1]^2 + g[j, 2]^2/dmu[2, 2]^2), df = (I - 1) * (J - 1))
+  pvalcol[j] <- 1 - pchisq(t.inertia* (Jmass[j,j])*(g[j, a1]^2/dmu[a1, a1]^2 + g[j, a2]^2/dmu[a2, a2]^2), df = (I - 1) )
 #browser()
         }
     }
@@ -151,6 +143,6 @@ pvalcol[j] <- 1 - pchisq(t.inertia * (1/Jmass[j,j] - sum(b[j, 3:M]^2))^(-1) * (g
    dimnames(row.summ) <- list(paste(Inames[[1]]), paste(summ.name))
     col.summ <- cbind(hlax1.col, hlax2.col, area.col, pvalcol)
     dimnames(col.summ) <- list(paste(Jnames[[1]]), paste(summ.name))
-invisible(  list(eccentricity = eccentricity, row.summ = row.summ, 
+invisible( list(eccentricity = eccentricity, row.summ = row.summ, 
         col.summ = col.summ))
  }
